#
# spec file for package dosbox
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dosbox
BuildRequires:  Mesa-devel
BuildRequires:  SDL_sound-devel
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(sdl)
%if 0%suse_version > 1020
BuildRequires:  SDL_net-devel
%else
BuildRequires:  SDL_net
%endif
Url:            http://dosbox.sourceforge.net/
Version:        0.74
Release:        26.2
Summary:        DOS Emulator Well-Suited for Playing Games
License:        GPL-2.0+
Group:          System/Emulators/PC
Source:         http://switch.dl.sourceforge.net/sourceforge/dosbox/dosbox-%{version}.tar.gz
Source1:        dosbox.desktop
Source2:        dosbox.png
Patch:          dosbox-0.71-manpage.diff
Patch2:         gcc46.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
dosbox is a DOS emulator that, thanks to its good graphics and sound
emulation, is exceptionally well-suited for playing games. dosbox
features a built-in DOS operating system and transparent access to the
Linux file system and is therefore very easy to use.

%prep
%setup -q
%patch -p1
%patch2

%build
autoreconf -f -i
CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags} -fno-strict-aliasing" \
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install 
# we copy the docu ourself
rm -rf %{buildroot}%{_datadir}/doc/dosbox
install -d -m 755 %{buildroot}%{_datadir}/pixmaps
install -m 644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/dosbox.png
%suse_update_desktop_file -i %name Emulator

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS 
%{_bindir}/dosbox
%{_mandir}/man?/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%changelog
* Tue Dec 17 2013 martin.jakl@qbicon.cz
- added missing alsa dependency for midi support (bnc#855514)
* Mon Oct  8 2012 matthias@mailaender.name
- improved dosbox icon, from wikipedia entry.
- use pkgconfig(sdl) instead of SDL-devel buildrequires
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Mar 16 2011 ismail@namtrac.org
- Fix compilation with gcc 4.6
* Wed May 19 2010 lnussel@suse.de
- new version 0.74
  * Several small game specific fixes/hacks/support. (Offensive, Roadhog, GTA
    installer, Kingdom O' Magic soundcard detection, Pirate booter, Armored
    Fist installer)
  * Add the S3-specific 640x480 256 color mode. (fixes regression in "Wooden
    Ships and Iron Men" and "I Have No Mouth And I Must Scream")
  * Fix a stack overflow that could crash DOSBox.
  * Add fake microphone input. (fixes Talking Parrot)
  * Modify adlib turn off code, so that it doesn't turn off in cases where the
    same sound is repeated over and over again.
  * Several small fixes to the CDROM audio code.(HOMM2, Redneck Rampage and
    others)
  * Several improvements to the CDROM emulation code. (fixes Alpha Storm and GT
    Racing 97)
  * Some small CPU fixes that might fix something.
  * Handle opcode 0xff subcode 7 as invalid instruction. (fixes dif-2 & others)
  * Some hercules fixes. (Testdrive)
  * Improve support for blanked parts that wrap around to the start of the
    screen. (fixes Magic Circle demo and Sid&Al)
  * Remove old OPL cores as the new ones seem to work very nicely.
  * Modify movie recording code so that the movies aren't corrupt when you exit
    dosbox without stopping the movie.
  * Change RGB3x scaler to look more pretty.
  * Improve initial register values compatility of the GUS.
  * Added autodetection for Gameblaster. (games can find it now)
  * Change render preferences a bit to be more compatible with Windows 7.
  * Add DOS fixes to terminate program. (fixes Fortune Teller)
  * Add FFREEP. (fixes Trucks)
  * Improve FPU ST80 in C mode when writing zero. (fixes Antigok)
  * Add special int10 scanline function. (fixes mz700 and probably lots of
    games that mess with them)
  * Fix scrolling in rarely used video modes. (fixes Orphee)
  * Modify game specific hacks a bit so that Kick off 3 works again.
  * Lots of fixes to the INT10 video parameter table. (Seven spirits of ra and
    others)
  * Add VGA blanking in machine=vgaonly. (used by Alien Carnage)
  * CGA, PCJr, Tandy: Add video blanking, change display start latch timing,
    sync pulse width correction.
  * PCJr, Tandy: implement vertical retrace interrupt.
  * PCJr, CGA: line-by-line video emulation.
  * PCJr: support on-screen change of color modes 4medium to 16low. (used by
    Ghostbusters booter)
  * Hercules: Add green and amber monochrome support.
  * All machines: only update the video timing when needed. (Jungle Hunt,
    others that synchronize to the video screen might profit)
  * Several small DOS fixes.
  * Some UMB related fixes. (The Legacy without UMB)
  * Fix version number of DSP for SB 1.5. (fixes a few games)
  * Several VGA emulation improvements. (Allertone football manager)
  * Some Tandy fixes. (Mech Warrior)
  * Small improvements and fixes to the OPL emulation.
  * Add low level Tandy DAC emulation.
  * Some EMS fixes. (fixes Mortal Kombat and others)
  * Change SoundBlaster DSP reset mechanism, add sb irq acknowledge logic.
    (fixes stmik*based applications)
  * Some interrupt pointer location modifications. (fixes Tinker Tales)
  * Some fixes to the BOOT code. (fixes Last Mission)
  * Respect write-only file information. (fixes Champions of Zulala)
  * Some RTC fix. (fixes Tully Bodine and others)
  * Improve mouse emulation to work better with Water World.
  * Hopefully fix the translation of the configuration file.
  * Speed up and fixes for the recompiler core. (pitfall2 pcjr)
  * Change memory start location. (fixes 7th Guest installer)
  * Several fixes to the batch file handling. (Shift and use the typed first %%0
    instead of the parsed %%0)
  * Improve file redirection and redirected line ends. (fixes Phantasmagoria 2
    DOS installer)
  * Fix compilation with new MAC os X version.
  * Add 16C550A FIFO support to the serial port emulation.
  * Improve modem emulation to get higher speeds.
  * Change default samplerates to 44100, blocksize to 1024 and prebuffer to 20,
    so that hopefully certain soundcards produce more fluent sound playback.
  * Add some rarely used, but for some games critical flags to the internal
    commands.
  * Add -userconf flag, so that the userspecific configuration can easily be
    used together with *conf configfile.
  * Improve internal timing with repeating timers (especially with the dynamic
    core).
* Thu May 28 2009 lnussel@suse.de
- new version 0.73
  * Support for more graphics modes and cards.
  * Improved Vista support.
  * New OPL emulation cores.
  * Sound fixes and improvements for Mac OS X.
  * Lots of compatibility fixes.
  * Lots of cdrom detection improvements.
  * Lots of memory (EMS/XMS) improvements.
  * Various fixes and enhancements for the recompiling core.
  * Support for evdev.
  * Lots of DOS fixes.
  * Slightly faster!
  * More stable.
* Tue Dec  4 2007 lnussel@suse.de
- fix wrong use of strncat
* Mon Oct 15 2007 lnussel@suse.de
- fix build with gcc 4.3
* Tue Aug 28 2007 lnussel@suse.de
- new version 0.72
  * Fixed unitialized variable in joystick. (Fixes crashes on Vista and
    Mac OS X)
  * Some bugfixes and speedups to the 64 bit recompiling core.
  * Fixed sign flag on soundblaster dma transfers (Space Quest 6 intro)
  * Fixed a bug in keyboard layout processing code and fixed certain
    layouts.
  * Fixed Dreamweb.
  * Improved speed unlocking when running cycles=max.
  * Fixed a crash related to the tab completion in the shell.
  * Improved aspect correction code. Should now be like how a real monitor
    handles it.
  * Fixed a bug in the xms status report code. (Blake Stone 1.0 shareware)
  * Added a lot more keyboard layouts.
  * Fix crash related to changing the scaler before a screen was created.
  * Hopefully fixed compilation on *bsd.
  * Enabled auto cpu core selection for recompiling core as well.
  * Made the used joystick selectable when 4axis is specified.
  * Added some hints for inexperienced DOS users to the shell.
* Mon Jul 30 2007 lnussel@suse.de
- new version 0.71
  * Added a new recompiling cpu core which is easier to port!
  * Added a x86_64 and a mipsel_32 recompiling core.
  * Fixed hangups on certain platforms after long gameplay of
    several games.
  * Fix several joystick bugs.
  * Improved cdrom support. (fixes for audio, iso and detection.)
  * Improved SVGA and VESA. (detection and display)
  * Fixed a few textmodes and improved ansi emulation a bit.
  * Fixed pcspeaker and certain types of soundeffects.
  * Added undocumented mousebackdoor.
  * Made mount and imgmount a bit easier to use. (ioctl by default,
    support for ~ and ~username, auto size guessing for images)
  * Fix a few compilation problems on various hosts and a general
    code cleanup.
  * Several small fixes that improve compatibility.
* Fri May 25 2007 lnussel@suse.de
- dont rm -rf %%buildroot in %%prep
* Mon Mar  5 2007 lnussel@suse.de
- new version 0.70
  * Speed up the dynamic cpu core (certain games get much faster).
  * Added a dynamic fpu on x86 hosts.
  * Improved the cycle guessing code (and make it default).
  * Better and more configurable joystick support.
  * Improved the image and fat drives.
  * Added nullmodem emulation.
  * Various win 3.x enhanchments (video/audio/ems/win32s).
  * Improved CDROM detection and support.
  * Speed up the screen drawing code.
  * Added support for different keyboard layouts.
  * Various fixes to the (C/E/V)GA emulation.
  * Extended and improved all types of emulated memory. (umb/ems/xms)
  * Dynamic core should work on Intel Macs.
  * Various timer related fixes.
  * Added a few more graphic scalers.
* Mon Feb 12 2007 lnussel@suse.de
- fix overflow of a global variable reported by gcc
* Tue Jun 27 2006 lnussel@suse.de
- fix use of uninitialized variables (#188290)
* Mon May  8 2006 lnussel@suse.de
- new version 0.65
  * 4/15/16/32bpp VESA mode support
  * Lot's of fixes for better vga compatibility
  * Improved CGA composite output
  * Added video capturing to avi
  * Improved screen updating for more speed
  * PCjr machine mode added
  * Speedup cpu cores and fix endian issues
  * FPU core speedup with assembly
  * Improved keyboard and bios handling
  * Lockfree mouse mode added again
  * Improved builtin dos with umbs and better fat support
  * Added VCPI emulation and fixed some issues with ems
  * Improved support for booter games
  * Modem and IPX support improved for multiplayer
* Fri Jan 27 2006 lnussel@suse.de
- add Mesa-devel, libpng-devel and gcc-c++ to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 lnussel@suse.de
- add -fno-strict-aliasing
- fix uninitialized variables
* Tue Oct 18 2005 lnussel@suse.de
- fix build with gcc 4.1
* Sun Oct  2 2005 stbinner@suse.de
- GenericName = short, Comment = verbose
* Fri Apr 22 2005 lnussel@suse.de
- fix another build failure on x86_64
* Fri Apr  8 2005 lnussel@suse.de
- fix build with gcc4
- add icon
* Mon Nov 29 2004 lnussel@suse.de
- update to version 0.63
* Tue Oct 12 2004 lnussel@suse.de
- update to version 0.62
* Tue Feb 17 2004 lnussel@suse.de
- update to version 0.61
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep  1 2003 adrian@suse.de
- use Emulator Category
* Tue Aug 19 2003 lnussel@suse.de
- new version 0.58
- use /etc/dosbox.conf or ~/.dosbox.conf as config file
- desktop file
* Tue May 27 2003 coolo@suse.de
- use BuildRoot
* Fri Aug  2 2002 uli@suse.de
- initial package
